==> v0.7.zip: authentic2-auth-fedict/src/authentic2_auth_fedict/__init__.py <==
# authentic2_auth_fedict - Fedict authentication for Authentic
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils.translation import ugettext_lazy as _


class Plugin(object):
    def get_before_urls(self):
        from . import urls
        return urls.urlpatterns

    def get_apps(self):
        return ['mellon', __name__]

    def get_authentication_backends(self):
        return ['authentic2_auth_fedict.backends.FedictBackend']

    def get_auth_frontends(self):
        return ['authentic2_auth_fedict.auth_frontends.FedictFrontend']

    def redirect_logout_list(self, request, next_url=None):
        from mellon.views import logout
        if 'mellon_session' in request.session:
            response = logout(request)
            if 'Location' in response:
                return [response['Location']]
        return []

    def registration_form_prefill(self, request):
        if request.token.get('first_name'):
            return [{'first_name': [request.token.get('first_name')],
                     'last_name': [request.token.get('last_name')]}]
        else:
            return [{'first_name': [], 'last_name': []}]

    def attribute_kinds(self):
        from . import fields
        return [
            {'label': _('National Register Number'),
             'name': 'nrn',
             'field_class': fields.NrnField,},
            {'label': _('Date'),
             'name': 'date',
             'field_class': fields.DateField,},
            {'label': _('Street'),
             'name': 'street',
             'field_class': fields.StreetField,},
        ]

==> v0.9.zip: authentic2-auth-fedict/src/authentic2_auth_fedict/__init__.py <==
# authentic2_auth_fedict - Fedict authentication for Authentic
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils.translation import ugettext_lazy as _


class Plugin(object):
    def get_before_urls(self):
        from . import urls
        return urls.urlpatterns

    def get_apps(self):
        return ['mellon', __name__]

    def get_authentication_backends(self):
        return ['authentic2_auth_fedict.backends.FedictBackend']

    def get_auth_frontends(self):
        return ['authentic2_auth_fedict.auth_frontends.FedictFrontend']

    def redirect_logout_list(self, request, next_url=None):
        from mellon.views import logout
        if 'mellon_session' in request.session:
            response = logout(request)
            if 'Location' in response:
                return [response['Location']]
        return []

    def registration_form_prefill(self, request):
        if request.token.get('first_name'):
            return [{'first_name': [request.token.get('first_name')],
                     'last_name': [request.token.get('last_name')]}]
        else:
            return [{'first_name': [], 'last_name': []}]

    def attribute_kinds(self):
        from . import fields
        return [
            {'label': _('National Register Number'),
             'name': 'nrn',
             'field_class': fields.NrnField, },
            {'label': _('Date'),
             'name': 'date',
             'field_class': fields.DateField, },
            {'label': _('Street'),
             'name': 'street',
             'field_class': fields.StreetField, },
            {'label': _('House number'),
             'name': 'num_house',
             'field_class': fields.NumHouseField, },
            {'label': _('Phone number'),
             'name': 'phone',
             'field_class': fields.NumPhoneField, },
            {'label': _('Country'),
             'name': 'country',
             'field_class': fields.CountryField, },
        ]
